@@ -22,10 +22,13 @@
 
 ;;; Commentary:
 
-;; 
+;; Current version supports only MULE, FLIM, and SEMI.
 
 ;;; Code:
 
+(defvar rail-version "0.1"
+  "Version number of rail.el")
+
 (if (boundp 'mule-version)
     (progn
       (load "rail-table-mule")
@@ -36,7 +39,9 @@
       (defvar rail-ja-mule-version
         (let* ((whitespace (string-match " " mule-version))
                (mule-vernum (substring mule-version 0 whitespace))
-               (mule-codename (substring mule-version (+ 2 whitespace) (1- (length mule-version)))))
+               (mule-codename (substring mule-version
+					 (+ 2 whitespace)
+					 (1- (length mule-version)))))
           (format "%s (%s)"
                   mule-vernum
                   (or (cdr (assoc mule-codename rail-mule-version-alist))
@@ -45,8 +50,10 @@
       (and rail-emulate-genjis
            (setq mule-version rail-ja-mule-version))))
 
-(add-hook 'mime-setup-load-hook
-          '(lambda () (load "rail-main")))
+(if (featurep 'semi-def)
+    (load "rail-user-agent")
+  (add-hook 'mime-setup-load-hook
+	    '(lambda () (load "rail-user-agent"))))
 
 (provide 'rail)
 
